[tor-commits] [tor/master] Rename outvar to follow _out convention.

nickm at torproject.org nickm at torproject.org
Tue Apr 23 18:14:23 UTC 2019


commit 8bea0c2fa346b8f67e5c33a5c455d022049e34c6
Author: Nick Mathewson <nickm at torproject.org>
Date:   Tue Apr 23 14:14:17 2019 -0400

    Rename outvar to follow _out convention.
---
 src/feature/hs/hs_common.c | 8 ++++----
 src/feature/hs/hs_common.h | 3 ++-
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/src/feature/hs/hs_common.h b/src/feature/hs/hs_common.h
index fc0c39f94..3009780d9 100644
--- a/src/feature/hs/hs_common.h
+++ b/src/feature/hs/hs_common.h
@@ -241,7 +241,8 @@ void hs_get_responsible_hsdirs(const struct ed25519_public_key_t *blinded_pk,
                               int use_second_hsdir_index,
                               int for_fetching, smartlist_t *responsible_dirs);
 routerstatus_t *hs_pick_hsdir(smartlist_t *responsible_dirs,
-                              const char *req_key_str, bool *is_rate_limited);
+                              const char *req_key_str,
+                              bool *is_rate_limited_out);
 
 time_t hs_hsdir_requery_period(const or_options_t *options);
 time_t hs_lookup_last_hid_serv_request(routerstatus_t *hs_dir,



More information about the tor-commits mailing list
diff --git a/src/feature/hs/hs_common.c b/src/feature/hs/hs_common.c
index 11efe078a..d4736c286 100644
--- a/src/feature/hs/hs_common.c
+++ b/src/feature/hs/hs_common.c
@@ -1590,7 +1590,7 @@ hs_purge_last_hid_serv_requests(void)
  *  one that we should use to fetch a descriptor right now. Take into account
  *  previous failed attempts at fetching this descriptor from HSDirs using the
  *  string identifier <b>req_key_str</b>. We return whether we are rate limited
  *  into *<b>is_rate_limited</b> if it is not NULL.
  *
  *  Steals ownership of <b>responsible_dirs</b>.
  *
@@ -1598,7 +1598,7 @@ hs_purge_last_hid_serv_requests(void)
  *  NULL if no HSDirs are worth trying right now. */
 routerstatus_t *
 hs_pick_hsdir(smartlist_t *responsible_dirs, const char *req_key_str,
-              bool *is_rate_limited)
+              bool *is_rate_limited_out)
 {
   smartlist_t *usable_responsible_dirs = smartlist_new();
   const or_options_t *options = get_options();
@@ -1665,8 +1665,8 @@ hs_pick_hsdir(smartlist_t *responsible_dirs, const char *req_key_str,
     hs_lookup_last_hid_serv_request(hs_dir, req_key_str, now, 1);
   }
 
-  if (is_rate_limited != NULL) {
-    *is_rate_limited = rate_limited;
+  if (is_rate_limited_out != NULL) {
+    *is_rate_limited_out = rate_limited;
   }
 
   return hs_dir;
@@ -1590,7 +1590,7 @@ hs_purge_last_hid_serv_requests(void)
  *  previous failed attempts at fetching this descriptor from HSDirs using the
  *  string identifier <b>req_key_str</b>. We return whether we are rate limited
- *  into *<b>is_rate_limited</b> if it is not NULL.
+ *  into *<b>is_rate_limited_out</b> if it is not NULL.
  *
  *  Steals ownership of <b>responsible_dirs</b>.